=====
Usage
=====
Command line interface
----------------------
To use GIT Template Render (GITTR) command line tool:

.. click:: gittr.cli.cli:cli
  :prog: gittr
  :show-nested:

Library Usage
-------------
To use GIT Template Render (GITTR) in a project::

    import gittr.cli